@@ -6,6 +6,7 @@ from . helper import add_spaces
 from . helper import generate_random_digits_with_probability
 from . helper import generate_random_digits_with_positional_probability
 from . helper import category_id
+from . helper import convert_to_grayscale
 import logging
 
 logger = logging.getLogger(__name__)
@@ -19,5 +20,6 @@ __all__ = [
     "add_spaces",
     "generate_random_digits_with_probability",
     "generate_random_digits_with_positional_probability",
-    "category_id"
+    "category_id",
+    "convert_to_grayscale"
 ]
\ No newline at end of file
